@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-06-23'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-06-26'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -72,7 +72,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.004 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-23.
+This document describes version 0.005 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-26.
 
 =head1 SYNOPSIS
 
@@ -94,7 +94,7 @@ L<Log::Any> 1.045
 
 L<Log::Fast> v2.0.0
 
-L<Log::ger> 0.005
+L<Log::ger> 0.008
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -184,15 +184,15 @@ Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
  +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
  | participant                                       | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
- | Log::Any-null_adapter-1mil_log_trace              |       2.4 |       420 |        1   |   0.0013  |       6 |
- | Log::Fast-1mil_is_debug                           |       3.2 |       310 |        1.3 |   0.0021  |       6 |
- | Log::Any-no_adapter-1mil_is_trace                 |       4   |       250 |        1.7 |   0.0017  |       6 |
- | Log::Any-null_adapter-1mil_is_trace               |       4.1 |       250 |        1.7 |   0.0008  |       6 |
- | Log::Fast-1mil_DEBUG                              |      11   |        94 |        4.5 |   0.00074 |       6 |
- | Log::Any-no_adapter-1mil_log_trace                |      11   |        92 |        4.5 |   0.0003  |       7 |
- | Log::ger-1mil_log_is_trace                        |      20   |        60 |        7   |   0.00084 |       7 |
- | Log::ger-1mil_log_trace                           |      18   |        55 |        7.5 | 6.4e-05   |       6 |
- | Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace |      36   |        28 |       15   | 6.9e-05   |       6 |
+ | Log::Any-null_adapter-1mil_log_trace              |      2.48 |       403 |       1    |   0.00015 |       6 |
+ | Log::Fast-1mil_is_debug                           |      3.4  |       300 |       1.4  |   0.00039 |       6 |
+ | Log::Any-no_adapter-1mil_is_trace                 |      4.1  |       240 |       1.7  |   0.00043 |       6 |
+ | Log::Any-null_adapter-1mil_is_trace               |      4.16 |       240 |       1.68 |   0.00018 |       6 |
+ | Log::Any-no_adapter-1mil_log_trace                |     11    |        91 |       4.4  |   0.00032 |       7 |
+ | Log::Fast-1mil_DEBUG                              |     11    |        90 |       4.5  |   0.00057 |       6 |
+ | Log::ger-1mil_log_is_trace                        |     16    |        61 |       6.6  |   0.00019 |       6 |
+ | Log::ger-1mil_log_trace                           |     18    |        55 |       7.3  | 5.5e-05   |       6 |
+ | Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace |     38    |        26 |      15    |   0.00018 |       6 |
  +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
 
 
