@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Startup;
 
-our $VERSION = 0.004; # VERSION
+our $VERSION = 0.005; # VERSION
 
 our $results = [
   [
@@ -13,71 +13,80 @@ our $results = [
         participant => "use Log::Any + use Log::Any::Adapter::Screen",
         rate        => 120,
         samples     => 20,
-        time        => 8.4,
+        time        => 8.1,
         vs_slowest  => 1,
       },
       {
-        errors      => 2.5e-05,
+        errors      => 2.4e-05,
         modver      => 1.045,
         participant => "use Log::Any",
         rate        => 150,
         samples     => 20,
-        time        => 6.8,
+        time        => 6.7,
         vs_slowest  => 1.2,
       },
       {
-        errors      => 2.3e-05,
+        errors      => 2.2e-05,
         modver      => "",
         participant => "use Log::ger + use Log::ger::Output::Screen",
-        rate        => 180,
+        rate        => 190,
         samples     => 20,
-        time        => 5.6,
+        time        => 5.3,
         vs_slowest  => 1.5,
       },
       {
-        errors      => 8e-06,
+        errors      => 1.6e-05,
         modver      => "",
-        participant => "use Log::ger + use Log::ger::Plugin::OptAway",
-        rate        => 290,
-        samples     => 24,
-        time        => 3.5,
-        vs_slowest  => 2.4,
+        participant => "use Log::ger::Like::LogAny",
+        rate        => 230,
+        samples     => 20,
+        time        => 4.4,
+        vs_slowest  => 1.8,
       },
       {
-        errors      => 1.4e-05,
+        errors      => 1.8e-05,
+        modver      => "",
+        participant => "use Log::ger + use Log::ger::Plugin::OptAway",
+        rate        => 280,
+        samples     => 20,
+        time        => 3.6,
+        vs_slowest  => 2.3,
+      },
+      {
+        errors      => 9e-06,
         modver      => 0.15,
         participant => "use Log::Any",
         rate        => 330,
         samples     => 20,
         time        => 3,
-        vs_slowest  => 2.8,
+        vs_slowest  => 2.7,
       },
       {
-        errors      => 1.6e-05,
+        errors      => 1.3e-05,
         modver      => "",
         participant => "use Log::ger",
         rate        => 480,
-        samples     => 20,
+        samples     => 23,
         time        => 2.1,
-        vs_slowest  => 4,
+        vs_slowest  => 3.9,
       },
       {
-        errors      => 1e-05,
+        errors      => 1.1e-05,
         modver      => "",
         participant => "use Log::ger ()",
         rate        => 500,
         samples     => 20,
         time        => 2,
-        vs_slowest  => 4.2,
+        vs_slowest  => 4,
       },
       {
-        errors      => 1.5e-06,
+        errors      => 7.4e-06,
         modver      => "",
         participant => "baseline",
-        rate        => 850,
+        rate        => 830,
         samples     => 20,
         time        => 1.2,
-        vs_slowest  => 7.1,
+        vs_slowest  => 6.7,
       },
     ],
     {
@@ -197,7 +206,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3855.546,
+                                              speed                        => 3893.398,
                                               stepping                     => 3,
                                             },
                                             {
@@ -307,7 +316,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3796.976,
+                                              speed                        => 3813.976,
                                               stepping                     => 3,
                                             },
                                             {
@@ -417,7 +426,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3893.531,
+                                              speed                        => 3791.531,
                                               stepping                     => 3,
                                             },
                                             {
@@ -527,7 +536,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3733.359,
+                                              speed                        => "3788.210",
                                               stepping                     => 3,
                                             },
                                             {
@@ -637,7 +646,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3835.492,
+                                              speed                        => "3784.890",
                                               stepping                     => 3,
                                             },
                                             {
@@ -747,7 +756,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3777.718,
+                                              speed                        => "3897.250",
                                               stepping                     => 3,
                                             },
                                             {
@@ -857,7 +866,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3899.507,
+                                              speed                        => 3898.578,
                                               stepping                     => 3,
                                             },
                                             {
@@ -967,7 +976,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3899.109,
+                                              speed                        => 3898.578,
                                               stepping                     => 3,
                                             },
                                           ],
@@ -979,7 +988,8 @@ our $results = [
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.045,
                                             "Log::Any::Adapter::Screen" => 0.13,
-                                            "Log::ger" => 0.005,
+                                            "Log::ger" => 0.008,
+                                            "Log::ger::Like::LogAny" => 0.001,
                                             "Log::ger::Output::Screen" => 0.004,
                                             "Log::ger::Plugin::OptAway" => 0.003,
                                             "perl" => "v5.24.0",
@@ -990,9 +1000,9 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [0.15, 1.045],
+                                            [1.045, 0.15],
                                             "participant",
-                                            [0 .. 6],
+                                            [0 .. 7],
                                           ],
       "func.platform_info"             => {
                                             archname => "x86_64",
@@ -1019,12 +1029,12 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
-      "func.scenario_module_md5sum"    => "7c56515d62658ed15e18ec6c018147b6",
-      "func.scenario_module_mtime"     => 1498215318,
-      "func.scenario_module_sha1sum"   => "c5284e1bfa8aedea8b177412805fb78b2ba1ad58",
-      "func.scenario_module_sha256sum" => "4fcd40e363b29a16cdb4df42670ff97f621d91151311fbf0d0e1ff6eee631792",
+      "func.scenario_module_md5sum"    => "65405378a4ed788ea870a5ec171b0914",
+      "func.scenario_module_mtime"     => 1498451419,
+      "func.scenario_module_sha1sum"   => "45c8fce112802f29e26307221c554cb509e0948f",
+      "func.scenario_module_sha256sum" => "d2d0107b8c0a6eb02a1bbdd1c1a0ffab446371c4d310be7aa8b2dc9c2b2451ac",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498215551.8682,
+      "func.time_start"                => 1498451479.95537,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
